@echo off
@rem *******************************************************************
@rem * Licensed Materials - Property of IBM
@rem * "Restricted Materials of IBM"
@rem * 5724-N93
@rem * (C) Copyright IBM Corp. 2007 All Rights Reserved.
@rem * US Government Users Restricted Rights - Use, duplication or
@rem * disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
@rem *******************************************************************

@rem initialize variables
SETLOCAL
set RC=0
set INSTALLSRC=%~dp0
pushd..
set TDWBDIR=%CD%
popd
set OPTIONAL=

rem *** MODIFY THIS IF YOUR WAS USES A LONG INSTALLATION PATH ***
set TEMPDIR=

rem *** MODIFY THIS IF YOUR MASTER TAG DOES NOT CONTAIN A VALID WAS PROFILE PATH ***
set TDWB_WAS_PROFILE_PATH=


@rem The range for return codes for this script is: [21 - 49].
@rem The reason is explained below for each return code.
@rem 0   - successful
@rem 21   - bad usage
@rem 22   - invalid command line parameters
@rem 23   - TDWB install location doesn't exist
@rem 24   - WAS Profile Path doesn't exist
@rem 26   - error updating WAR module

:parseParams
if "%1" == "" goto setEnvVars
if /I "%1" == "-user"        set OPTIONAL=%OPTIONAL% -user %2& goto goodParam
if /I "%1" == "-password"    set OPTIONAL=%OPTIONAL% -password %2& goto goodParam
if /I "%1" == "-usage" goto usage
if /I "%1" == "-help"  goto usage
goto usage

:goodParam
shift
shift
goto parseParams


:setEnvVars
set BRIDGE_APPLICATION=TWSAgent
set BRIDGE_EAR_FILE=%INSTALLSRC:"=%TWSAgentEAR.ear
set MASTERTAG=%TDWBDIR:"=%\Install\master.tag
IF DEFINED TEMPDIR set TEMPDIR=-javaoption "-Dworkspace.user.root=%TEMPDIR%"

:checkTDWBRoot
if not exist "%MASTERTAG:"=%" goto usageNoTDWBRoot


:updateWAR
echo.
echo Updating the %BRIDGE_APPLICATION% application ...
echo.
@rem setting the enviroment from master tag
set STR=%TDWBDIR:\=/%
set TDWBDIR=%STR%
for /f "eol=# Tokens=1,3* usebackq delims=  " %%a in ("%MASTERTAG%") do set "%%a"2>%TEMP%\ifix1.2.0.1


:checkWASPROFILEPATH
if not exist "%TDWB_WAS_PROFILE_PATH:"=%" goto noWasProfile

@rem setting the enviroment from TWAAgentConfig
set TWSAgent.retrylink=
for /f "eol=# Tokens=1,3* usebackq delims=  " %%a in ("%TDWBDIR:"=%\config\TWSAgentConfig.properties") do set %%a

if "%TWSAgent.retrylink%" == "" (
  call copy "%TDWBDIR:"=%\config\TWSAgentConfig.properties" "%TDWBDIR:"=%\config\TWSAgentConfig.properties.orig" 1>NUL
  call echo # TWS Agent Retry link Configuration  >> "%TDWBDIR:"=%\config\TWSAgentConfig.properties"
  call echo #-----------------------------------  >> "%TDWBDIR:"=%\config\TWSAgentConfig.properties"
  call echo TWSAgent.retrylink=600 >> "%TDWBDIR:"=%\config\TWSAgentConfig.properties"
)

call "%TDWB_WAS_PROFILE_PATH:"=%\bin\wsadmin.bat" %OPTIONAL% -lang jython -javaoption "-Dpython.path=%~dp0." %TEMPDIR% -f "%~dp0updateEAR.py" -application "%BRIDGE_APPLICATION%" -application_ear "%BRIDGE_EAR_FILE%"
if errorlevel 1 (
    echo Possible error updating module %BRIDGE_APPLICATION%, check %TDWB_WAS_PROFILE_PATH:"=%\logs\wsadmin.traceout.
    set RC=26
    goto done
)
goto done

:usageBadParam
echo ERROR: The command line parameter, %1, is invalid.
echo Use -usage to see the available command line options
set RC=22
goto done

:usageNoTDWBRoot
echo %TDWBDIR:"=% does not seem to be a valid TDWB install location.
echo Please check the existence of the file %MASTERTAG:"=%
echo.
set RC=23
goto done

:noWasProfile
echo The master tag in the TDWB install location, (%TDWBDIR%\Install\master.tag), does not contain a valid WAS Profile Path.
echo Please specify the proper location for the WAS Profile Path installation.
echo.
set RC=24
goto done

:usage
echo.
echo Usage:
echo   install [-user wasUser -password wasUserPassword]
set RC=21
goto explainParams


:explainParams
echo.
echo   wasUser          - Was Administrator
echo   wasUserPassword  - Was Administrator Password
echo.
goto done

:done
if %RC% == 0 (
echo "The update of %BRIDGE_APPLICATION% application is complete"
)
ENDLOCAL

